==> Java-Swing-0.02.tar.gz: Java-Swing-0.02/java/PerlMenuKeyListener.java <==
import javax.swing.event.MenuKeyListener;
import org.perl.inline.java.*;

public class      PerlMenuKeyListener
       extends    InlineJavaPerlCaller
       implements MenuKeyListener
{
    String sender;
    String callbacks;

    public PerlMenuKeyListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void menuKeyTyped(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuKeyListener",
                "_MenuKeyListener",
                new Object[] {sender, callbacks, "menuKeyTyped", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuKeyPressed(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuKeyListener",
                "_MenuKeyListener",
                new Object[] {sender, callbacks, "menuKeyPressed", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuKeyReleased(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing::MenuKeyListener",
                "_MenuKeyListener",
                new Object[] {sender, callbacks, "menuKeyReleased", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}

==> Java-Swing-0.13.tar.gz: Java-Swing-0.13/java/PerlMenuKeyListener.java <==
import javax.swing.event.MenuKeyListener;
import org.perl.inline.java.*;

public class      PerlMenuKeyListener
       extends    InlineJavaPerlCaller
       implements MenuKeyListener
{
    String sender;
    String callbacks;

    public PerlMenuKeyListener() throws InlineJavaException { }

    public PerlMenuKeyListener(String sender, String callbacks)
        throws InlineJavaException
    {
        this.sender    = sender;
        this.callbacks = callbacks;
    }

    public void setSender   (String sender)    { this.sender    = sender; }
    public void setCallbacks(String callbacks) { this.callbacks = callbacks; }

    public void menuKeyTyped(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuKeyTyped", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuKeyPressed(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuKeyPressed", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
    public void menuKeyReleased(javax.swing.event.MenuKeyEvent event)  {
        try {
            CallPerl(
                "Java::Swing",
                "_Listener",
                new Object[] {sender, callbacks, "menuKeyReleased", event}
            );
        }
        catch (InlineJavaPerlException ijpe) {
            System.err.println("couldn't call perl ijpe: " + ijpe);
        }
        catch (InlineJavaException ije) {
            System.err.println("couldn't call perl ije: " + ije);
        }
    }
}
